==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-tree-item-component-event-args.js <==
import { TreeItemComponentEventArgs as TreeItemComponentEventArgs_internal } from "./TreeItemComponentEventArgs";
var IgrTreeItemComponentEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrTreeItemComponentEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrTreeItemComponentEventArgs.prototype.createImplementation = function () {
        return new TreeItemComponentEventArgs_internal();
    };
    Object.defineProperty(IgrTreeItemComponentEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrTreeItemComponentEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrTreeItemComponentEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrTreeItemComponentEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrTreeItemComponentEventArgs;
}());
export { IgrTreeItemComponentEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-tree-item-component-event-args.js <==
import { IgrTreeItem } from "./igr-tree-item";
import { TreeItemComponentEventArgs as TreeItemComponentEventArgs_internal } from "./TreeItemComponentEventArgs";
var IgrTreeItemComponentEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrTreeItemComponentEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrTreeItemComponentEventArgs.prototype.createImplementation = function () {
        return new TreeItemComponentEventArgs_internal();
    };
    Object.defineProperty(IgrTreeItemComponentEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrTreeItemComponentEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrTreeItemComponentEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrTreeItemComponentEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrTreeItem({});
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrTreeItemComponentEventArgs;
}());
export { IgrTreeItemComponentEventArgs };
